The following material designs icons are used here:

* audit: "event list" (https://fonts.google.com/icons?selected=Material%20Symbols%20Outlined%3Aevent_list%3AFILL%400%3Bwght%40400%3BGRAD%400%3Bopsz%4048)
* bug: "bug report" (https://fonts.google.com/icons?selected=Material%20Symbols%20Outlined%3Abug_report%3AFILL%400%3Bwght%40400%3BGRAD%400%3Bopsz%4048)
* change: "change circle" (https://fonts.google.com/icons?selected=Material%20Symbols%20Outlined%3Achange_circle%3AFILL%400%3Bwght%40400%3BGRAD%400%3Bopsz%4048)
* connect: "computer" (https://fonts.google.com/icons?selected=Material%20Symbols%20Outlined%3Acomputer%3AFILL%400%3Bwght%40400%3BGRAD%400%3Bopsz%4048)
* sessions: "group" (https://fonts.google.com/icons?selected=Material%20Symbols%20Outlined%3Agroup%3AFILL%400%3Bwght%40400%3BGRAD%400%3Bopsz%4048)
* tokens: "key" (https://fonts.google.com/icons?selected=Material%20Symbols%20Outlined%3Akey%3AFILL%400%3Bwght%40400%3BGRAD%400%3Bopsz%4048)
